@@ -1,5 +1,5 @@
 // Analysis.h is a part of the PYTHIA event generator.
-// Copyright (C) 2022 Torbjorn Sjostrand.
+// Copyright (C) 2025 Torbjorn Sjostrand.
 // PYTHIA is licenced under the GNU GPL v2 or later, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
@@ -106,7 +106,7 @@ private:
 
   // Constants: could only be changed in the code itself.
   static const int    NSTUDYMIN, TIMESTOPRINT;
-  static const double MAJORMIN;
+  static const double CROSSMIN, MAJORMIN;
 
   // Properties of analysis.
   int    select;
