@@ -1,5 +1,5 @@
 // BeamParticle.h is a part of the PYTHIA event generator.
-// Copyright (C) 2022 Torbjorn Sjostrand.
+// Copyright (C) 2025 Torbjorn Sjostrand.
 // PYTHIA is licenced under the GNU GPL v2 or later, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
@@ -141,11 +141,11 @@ public:
     maxValQuark(), companionPower(), valencePowerMeson(), valencePowerUinP(),
     valencePowerDinP(), valenceDiqEnhance(), pickQuarkNorm(), pickQuarkPower(),
     diffPrimKTwidth(), diffLargeMassSuppress(), beamSat(), gluonPower(),
-    xGluonCutoff(), idBeam(), idBeamAbs(), idVMDBeam(), mBeam(), mVMDBeam(),
-    scaleVMDBeam(), isUnresolvedBeam(), isLeptonBeam(), isHadronBeam(),
-    isMesonBeam(), isBaryonBeam(), isGammaBeam(), nValKinds(), idVal(), nVal(),
-    idSave(), iSkipSave(), nValLeft(), xqgTot(), xqVal(), xqgSea(),
-    xqCompSum(), doISR(), doMPI(), doND(), isResolvedGamma(),
+    xGluonCutoff(), heavyQuarkEnhance(), idBeam(), idBeamAbs(), idVMDBeam(),
+    mBeam(), mVMDBeam(), scaleVMDBeam(), isUnresolvedBeam(), isLeptonBeam(),
+    isHadronBeam(), isMesonBeam(), isBaryonBeam(), isGammaBeam(), nValKinds(),
+    idVal(), nVal(), idSave(), iSkipSave(), nValLeft(), xqgTot(), xqVal(),
+    xqgSea(), xqCompSum(), doISR(), doMPI(), doND(), isResolvedGamma(),
     hasResGammaInBeam(), isResUnres(), hasVMDstateInBeam(), initGammaBeam(),
     pTminISR(), pTminMPI(), pT2gm2qqbar(), iGamVal(), iPosVal(), gammaMode(),
     xGm(), Q2gm(), kTgamma(), phiGamma(), cPowerCache(-100), xsCache(-1),
@@ -289,6 +289,8 @@ public:
   // Overload index operator to access a resolved parton from the list.
   ResolvedParton& operator[](int i) {return resolved[i];}
   const ResolvedParton& operator[](int i) const {return resolved[i];}
+  ResolvedParton& at(int i) {return resolved.at(i);}
+  const ResolvedParton& at(int i) const {return resolved.at(i);}
 
   // Total number of partons extracted from beam, and initiators only.
   int size() const {return resolved.size();}
@@ -379,12 +381,12 @@ public:
 
   // Set and get the state (resolved and/or unresolved) of photon beam.
   void resolvedGamma(bool isResolved) { isResolvedGamma = isResolved; }
-  bool resolvedGamma()                { return isResolvedGamma; }
+  bool resolvedGamma() const          { return isResolvedGamma; }
   void setGammaMode(int gammaModeIn);
-  int  getGammaMode()                 { return gammaMode; }
-  bool isResolvedUnresolved()         { return isResUnres; }
+  int  getGammaMode() const           { return gammaMode; }
+  bool isResolvedUnresolved() const   { return isResUnres; }
   void initGammaInBeam()              { initGammaBeam = true; }
-  bool gammaInBeam()                  { return initGammaBeam; }
+  bool gammaInBeam() const            { return initGammaBeam; }
 
   // Set state of VMD inside gamma.
   void setVMDstate(bool isVMDIn, int idIn, double mIn, double scaleIn,
@@ -462,6 +464,19 @@ public:
 
 private:
 
+  // After initInfoPtr, remove circular dependencies.
+  virtual void onInitInfoPtr() override {
+    beamAPtr    = nullptr;
+    beamBPtr    = nullptr;
+    beamPomAPtr = nullptr;
+    beamPomBPtr = nullptr;
+    beamGamAPtr = nullptr;
+    beamGamBPtr = nullptr;
+    beamVMDAPtr = nullptr;
+    beamVMDBPtr = nullptr;
+    userHooksPtr = nullptr;
+  }
+
   // Constants: could only be changed in the code itself.
   static const double XMINUNRESOLVED, POMERONMASS, XMAXCOMPANION, TINYZREL;
   static const int NMAX, NRANDOMTRIES;
@@ -488,7 +503,7 @@ private:
   double valencePowerMeson, valencePowerUinP, valencePowerDinP,
          valenceDiqEnhance, pickQuarkNorm, pickQuarkPower,
          diffPrimKTwidth, diffLargeMassSuppress, beamSat, gluonPower,
-         xGluonCutoff;
+         xGluonCutoff, heavyQuarkEnhance[6];
 
   // Basic properties of a beam particle.
   int    idBeam, idBeamAbs, idVMDBeam;
