@@ -1,5 +1,5 @@
 // DireWeightContainer.h is a part of the PYTHIA event generator.
-// Copyright (C) 2021 Stefan Prestel, Torbjorn Sjostrand.
+// Copyright (C) 2025 Stefan Prestel, Torbjorn Sjostrand.
 // PYTHIA is licenced under the GNU GPL v2 or later, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
@@ -29,18 +29,17 @@ public:
 
   // Constructor and destructor.
   DireSplittingQED(string idIn, int softRS, Settings* settings,
-    ParticleData* particleData, Rndm* rndm, BeamParticle* beamA,
-    BeamParticle* beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
-    DireSplittingQCD(idIn,
-      softRS,settings,particleData,rndm,beamA,beamB,coupSM,info, direInfo)
-    { init(); }
+    ParticleData* particleData, Rndm* rndm, BeamParticlePtr beamA,
+    BeamParticlePtr beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
+    DireSplittingQCD(idIn, softRS, settings, particleData, rndm, beamA, beamB,
+      coupSM,info, direInfo) {init();}
   virtual ~DireSplittingQED() {}
 
   void init();
 
-  // VARIABLES
+  // Class members.
   double sumCharge2Tot, sumCharge2L, sumCharge2Q, aem0, enhance, pT2min,
-         pT2minL, pT2minQ, pT2minForcePos;
+         pT2minL, pT2minQ, pT2minA, pT2minForcePos;
   bool doQEDshowerByQ, doQEDshowerByL, doForcePos;
 
   AlphaEM     alphaEM;
@@ -78,16 +77,16 @@ class Dire_fsr_qed_Q2QA : public DireSplittingQED {
 public:
 
   Dire_fsr_qed_Q2QA(string idIn, int softRS, Settings* settings,
-    ParticleData* particleData, Rndm* rndm, BeamParticle* beamA,
-    BeamParticle* beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
+    ParticleData* particleData, Rndm* rndm, BeamParticlePtr beamA,
+    BeamParticlePtr beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
     DireSplittingQED(idIn, softRS, settings, particleData, rndm, beamA, beamB,
       coupSM, info, direInfo){}
 
   bool canRadiate ( const Event&, pair<int,int>,
     unordered_map<string,bool> = unordered_map<string,bool>(),
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
   bool canRadiate ( const Event&, int iRadBef, int iRecBef,
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
 
   int kinMap ();
 
@@ -136,16 +135,16 @@ class Dire_fsr_qed_Q2AQ : public DireSplittingQED {
 public:
 
   Dire_fsr_qed_Q2AQ(string idIn, int softRS, Settings* settings,
-    ParticleData* particleData, Rndm* rndm, BeamParticle* beamA,
-    BeamParticle* beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
+    ParticleData* particleData, Rndm* rndm, BeamParticlePtr beamA,
+    BeamParticlePtr beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
     DireSplittingQED(idIn, softRS, settings, particleData, rndm, beamA, beamB,
       coupSM, info, direInfo){}
 
   bool canRadiate ( const Event&, pair<int,int>,
     unordered_map<string,bool> = unordered_map<string,bool>(),
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
   bool canRadiate ( const Event&, int iRadBef, int iRecBef,
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
 
   int kinMap ();
 
@@ -194,16 +193,16 @@ class Dire_fsr_qed_L2LA : public DireSplittingQED {
 public:
 
   Dire_fsr_qed_L2LA(string idIn, int softRS, Settings* settings,
-    ParticleData* particleData, Rndm* rndm, BeamParticle* beamA,
-    BeamParticle* beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
+    ParticleData* particleData, Rndm* rndm, BeamParticlePtr beamA,
+    BeamParticlePtr beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
     DireSplittingQED(idIn, softRS, settings, particleData, rndm, beamA, beamB,
       coupSM, info, direInfo){}
 
   bool canRadiate ( const Event&, pair<int,int>,
     unordered_map<string,bool> = unordered_map<string,bool>(),
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
   bool canRadiate ( const Event&, int iRadBef, int iRecBef,
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
 
   int kinMap ();
 
@@ -251,16 +250,16 @@ class Dire_fsr_qed_L2AL : public DireSplittingQED {
 public:
 
   Dire_fsr_qed_L2AL(string idIn, int softRS, Settings* settings,
-    ParticleData* particleData, Rndm* rndm, BeamParticle* beamA,
-    BeamParticle* beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
+    ParticleData* particleData, Rndm* rndm, BeamParticlePtr beamA,
+    BeamParticlePtr beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
     DireSplittingQED(idIn, softRS, settings, particleData, rndm, beamA, beamB,
       coupSM, info, direInfo){}
 
   bool canRadiate ( const Event&, pair<int,int>,
     unordered_map<string,bool> = unordered_map<string,bool>(),
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
   bool canRadiate ( const Event&, int iRadBef, int iRecBef,
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
 
   int kinMap ();
 
@@ -312,21 +311,21 @@ public:
 
   Dire_fsr_qed_A2FF(int idRadAfterIn, string idIn, int softRS,
     Settings* settings,
-    ParticleData* particleData, Rndm* rndm, BeamParticle* beamA,
-    BeamParticle* beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
+    ParticleData* particleData, Rndm* rndm, BeamParticlePtr beamA,
+    BeamParticlePtr beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
     DireSplittingQED(idIn,
     softRS, settings, particleData, rndm, beamA, beamB, coupSM, info,
     direInfo),
     idRadAfterSave(idRadAfterIn), nchSaved(1) {}
   bool canRadiate ( const Event& state, pair<int,int> ints,
     unordered_map<string,bool> = unordered_map<string,bool>(),
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL) {
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr) {
     return ( state[ints.first].isFinal()
           && state[ints.first].id() == 22
           && state[ints.second].isCharged());
   }
   bool canRadiate ( const Event& state, int iRadBef, int iRecBef,
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL) {
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr) {
     return ( state[iRadBef].isFinal()
           && state[iRadBef].id() == 22
           && state[iRecBef].isCharged());
@@ -528,16 +527,16 @@ class Dire_isr_qed_Q2QA : public DireSplittingQED {
 public:
 
   Dire_isr_qed_Q2QA(string idIn, int softRS, Settings* settings,
-    ParticleData* particleData, Rndm* rndm, BeamParticle* beamA,
-    BeamParticle* beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
+    ParticleData* particleData, Rndm* rndm, BeamParticlePtr beamA,
+    BeamParticlePtr beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
     DireSplittingQED(idIn, softRS, settings, particleData, rndm, beamA, beamB,
       coupSM, info, direInfo){}
 
   bool canRadiate ( const Event&, pair<int,int>,
     unordered_map<string,bool> = unordered_map<string,bool>(),
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
   bool canRadiate ( const Event&, int iRadBef, int iRecBef,
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
 
   int kinMap ();
 
@@ -584,16 +583,16 @@ class Dire_isr_qed_A2QQ : public DireSplittingQED {
 public:
 
   Dire_isr_qed_A2QQ(string idIn, int softRS, Settings* settings,
-    ParticleData* particleData, Rndm* rndm, BeamParticle* beamA,
-    BeamParticle* beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
+    ParticleData* particleData, Rndm* rndm, BeamParticlePtr beamA,
+    BeamParticlePtr beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
     DireSplittingQED(idIn, softRS, settings, particleData, rndm, beamA, beamB,
       coupSM, info, direInfo){}
 
   bool canRadiate ( const Event&, pair<int,int>,
     unordered_map<string,bool> = unordered_map<string,bool>(),
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
   bool canRadiate ( const Event&, int iRadBef, int iRecBef,
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
 
   int kinMap ();
 
@@ -638,16 +637,16 @@ class Dire_isr_qed_Q2AQ : public DireSplittingQED {
 public:
 
   Dire_isr_qed_Q2AQ(string idIn, int softRS, Settings* settings,
-    ParticleData* particleData, Rndm* rndm, BeamParticle* beamA,
-    BeamParticle* beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
+    ParticleData* particleData, Rndm* rndm, BeamParticlePtr beamA,
+    BeamParticlePtr beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
     DireSplittingQED(idIn, softRS, settings, particleData, rndm, beamA, beamB,
       coupSM, info, direInfo){}
 
   bool canRadiate ( const Event&, pair<int,int>,
     unordered_map<string,bool> = unordered_map<string,bool>(),
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
   bool canRadiate ( const Event&, int iRadBef, int iRecBef,
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
 
   int kinMap ();
 
@@ -695,16 +694,16 @@ class Dire_isr_qed_L2LA : public DireSplittingQED {
 public:
 
   Dire_isr_qed_L2LA(string idIn, int softRS, Settings* settings,
-    ParticleData* particleData, Rndm* rndm, BeamParticle* beamA,
-    BeamParticle* beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
+    ParticleData* particleData, Rndm* rndm, BeamParticlePtr beamA,
+    BeamParticlePtr beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
     DireSplittingQED(idIn, softRS, settings, particleData, rndm, beamA, beamB,
       coupSM, info, direInfo){}
 
   bool canRadiate ( const Event&, pair<int,int>,
     unordered_map<string,bool> = unordered_map<string,bool>(),
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
   bool canRadiate ( const Event&, int iRadBef, int iRecBef,
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
 
   int kinMap ();
 
@@ -750,16 +749,16 @@ class Dire_isr_qed_A2LL : public DireSplittingQED {
 public:
 
   Dire_isr_qed_A2LL(string idIn, int softRS, Settings* settings,
-    ParticleData* particleData, Rndm* rndm, BeamParticle* beamA,
-    BeamParticle* beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
+    ParticleData* particleData, Rndm* rndm, BeamParticlePtr beamA,
+    BeamParticlePtr beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
     DireSplittingQED(idIn, softRS, settings, particleData, rndm, beamA, beamB,
       coupSM, info, direInfo){}
 
   bool canRadiate ( const Event&, pair<int,int>,
     unordered_map<string,bool> = unordered_map<string,bool>(),
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
   bool canRadiate ( const Event&, int iRadBef, int iRecBef,
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
 
   int kinMap ();
 
@@ -803,16 +802,16 @@ class Dire_isr_qed_L2AL : public DireSplittingQED {
 public:
 
   Dire_isr_qed_L2AL(string idIn, int softRS, Settings* settings,
-    ParticleData* particleData, Rndm* rndm, BeamParticle* beamA,
-    BeamParticle* beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
+    ParticleData* particleData, Rndm* rndm, BeamParticlePtr beamA,
+    BeamParticlePtr beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
     DireSplittingQED(idIn, softRS, settings, particleData, rndm, beamA, beamB,
       coupSM, info, direInfo){}
 
   bool canRadiate ( const Event&, pair<int,int>,
     unordered_map<string,bool> = unordered_map<string,bool>(),
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
   bool canRadiate ( const Event&, int iRadBef, int iRecBef,
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
 
   int kinMap ();
 
@@ -858,16 +857,16 @@ class Dire_fsr_qed_Q2QA_notPartial : public DireSplittingQED {
 public:
 
   Dire_fsr_qed_Q2QA_notPartial(string idIn, int softRS, Settings* settings,
-    ParticleData* particleData, Rndm* rndm, BeamParticle* beamA,
-    BeamParticle* beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
+    ParticleData* particleData, Rndm* rndm, BeamParticlePtr beamA,
+    BeamParticlePtr beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
     DireSplittingQED(idIn, softRS, settings, particleData, rndm, beamA, beamB,
       coupSM, info, direInfo){}
 
   bool canRadiate ( const Event&, pair<int,int>,
     unordered_map<string,bool> = unordered_map<string,bool>(),
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
   bool canRadiate ( const Event&, int iRadBef, int iRecBef,
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
 
   int kinMap ();
   bool canUseForBranching() { return true; }
@@ -918,16 +917,16 @@ class Dire_fsr_qed_L2LA_notPartial : public DireSplittingQED {
 public:
 
   Dire_fsr_qed_L2LA_notPartial(string idIn, int softRS, Settings* settings,
-    ParticleData* particleData, Rndm* rndm, BeamParticle* beamA,
-    BeamParticle* beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
+    ParticleData* particleData, Rndm* rndm, BeamParticlePtr beamA,
+    BeamParticlePtr beamB, CoupSM* coupSM, Info* info, DireInfo* direInfo) :
     DireSplittingQED(idIn, softRS, settings, particleData, rndm, beamA, beamB,
       coupSM, info, direInfo){}
 
   bool canRadiate ( const Event&, pair<int,int>,
     unordered_map<string,bool> = unordered_map<string,bool>(),
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
   bool canRadiate ( const Event&, int iRadBef, int iRecBef,
-    Settings* = NULL, PartonSystems* = NULL, BeamParticle* = NULL);
+    Settings* = nullptr, PartonSystems* = nullptr, BeamParticlePtr = nullptr);
 
   int kinMap ();
   bool canUseForBranching() { return true; }
