@@ -1,5 +1,5 @@
 // SusyLesHouches.h is a part of the PYTHIA event generator.
-// Copyright (C) 2022 Torbjorn Sjostrand.
+// Copyright (C) 2025 Torbjorn Sjostrand.
 // Main authors of this file: N. Desai, P. Skands
 // PYTHIA is licenced under the GNU GPL v2 or later, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
@@ -28,7 +28,7 @@ namespace Pythia8 {
   public:
 
     //Constructor.
-    LHblock<T>() : idnow(0), qDRbar(), i(), val() {} ;
+    LHblock() : idnow(0), qDRbar(), i(), val() {} ;
 
     //Does block exist?
     bool exists() { return int(entry.size()) == 0 ? false : true ; };
@@ -129,7 +129,7 @@ namespace Pythia8 {
   template <int size> class LHmatrixBlock {
   public:
     //Constructor. Set uninitialized and explicitly zero.
-    LHmatrixBlock<size>() : entry(), qDRbar(), val() {
+    LHmatrixBlock() : entry(), qDRbar(), val() {
       initialized=false;
       for (i=1;i<=size;i++) {
         for (j=1;j<=size;j++) {
@@ -208,7 +208,7 @@ namespace Pythia8 {
   template <int size> class LHtensor3Block {
   public:
     //Constructor. Set uninitialized and explicitly zero.
-    LHtensor3Block<size>() : entry(), qDRbar(), val() {
+    LHtensor3Block() : entry(), qDRbar(), val() {
       initialized=false;
       for (i=1;i<=size;i++) {
         for (j=1;j<=size;j++) {
@@ -221,7 +221,7 @@ namespace Pythia8 {
 
     // Copy constructor.
     LHtensor3Block(const LHtensor3Block& m) : val(m.val) {
-      for (i=0;i<size;i++) for (j=0;j<=size;j++) for (k=0;k<=size;k++)
+      for (i=0;i<=size;i++) for (j=0;j<=size;j++) for (k=0;k<=size;k++)
         entry[i][j][k] = m(i,j,k);
       qDRbar = m.qDRbar;
       initialized = m.initialized; };
@@ -229,7 +229,7 @@ namespace Pythia8 {
     // Assignment.
     LHtensor3Block& operator=(const LHtensor3Block& m) {
       if (this != &m) {
-        for (i=0;i<size;i++) for (j=0;j<=size;j++) for (k=0;k<=size;k++)
+        for (i=0;i<=size;i++) for (j=0;j<=size;j++) for (k=0;k<=size;k++)
           entry[i][j][k] = m(i,j,k);
         qDRbar = m.qDRbar;
         initialized = m.initialized;
