@@ -1,5 +1,5 @@
 // UserHooks.h is a part of the PYTHIA event generator.
-// Copyright (C) 2021 Torbjorn Sjostrand.
+// Copyright (C) 2025 Torbjorn Sjostrand.
 // PYTHIA is licenced under the GNU GPL v2 or later, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
@@ -20,9 +20,10 @@ namespace Pythia8 {
 
 //==========================================================================
 
-// Forward references to the PhaseSpace and StringEnd classes.
+// Forward references.
 class PhaseSpace;
 class StringEnd;
+class HadronLevel;
 
 //==========================================================================
 
@@ -62,6 +63,15 @@ public:
   // Usage: doVetoProcessLevel( process).
   virtual bool doVetoProcessLevel(Event& ) {return false;}
 
+  // Possibility to set low energy cross sections.
+  // Usage: canSetLowEnergySigma(idA, idB).
+  virtual bool canSetLowEnergySigma(int, int) const {return false;}
+
+  // Set low energy cross sections for ids where canSetLowEnergySigma is true.
+  // Usage: doSetLowEnergySigma(idA, idB, eCM, mA, mB).
+  virtual double doSetLowEnergySigma(int, int, double, double, double) const {
+    return 0.;}
+
   // Possibility to veto resonance decay chain.
   virtual bool canVetoResonanceDecays() {return false;}
 
@@ -187,6 +197,9 @@ public:
   virtual bool doChangeFragPar( StringFlav*, StringZ*, StringPT*, int,
     double, vector<int>, const StringEnd* ) { return false;}
 
+  // Can veto hadrons in the fragmentation.
+  virtual bool canVetoFragmentation() { return false;}
+
   // Do a veto on a hadron just before it is added to the final state.
   // The StringEnd from which the the hadron was produced is included
   // for information.
@@ -194,10 +207,21 @@ public:
     { return false;}
 
   // Do a veto on a hadron just before it is added to the final state
-  // (final two hadron case).
+  // (final two hadron case).  Note that a veto from this function
+  // will refragment the whole string. If only the regeneration of
+  // the final two is desired, the doVetoFinalTwo function should be
+  // used instead.
   virtual bool doVetoFragmentation(Particle, Particle,
     const StringEnd*, const StringEnd* ) { return false;}
 
+  // Do a veto on a hadron just before it is added to the final state
+  // (final two hadron case). Note that a veto from this function will
+  // regenerate the final two. If the refragmentation of the whole
+  // string is desired, the doVetoFragmentation function should be
+  // used instead.
+  virtual bool doVetoFinalTwo(Particle, Particle,
+    const StringEnd*, const StringEnd* ) { return false;}
+
   // Possibility to veto an event after hadronization based
   // on event contents. Works as an early trigger to avoid
   // running the time consuming rescattering process on
@@ -213,14 +237,17 @@ public:
   // Set the overall impact parameter for the MPI treatment.
   virtual double doSetImpactParameter() { return 0.0; }
 
+  // Custom processing at the end of HadronLevel::next.
+  virtual bool onEndHadronLevel(HadronLevel&, Event&) { return true; }
+
 protected:
 
   // Constructor.
   UserHooks() {}
 
-  // After initInfoPtr, initialize workEvent
+  // After initInfoPtr, initialize workEvent.
   virtual void onInitInfoPtr() override {
-    // Set smart pointer to null, in order to avoid circular dependency
+    // Set smart pointer to null, in order to avoid circular dependency.
     userHooksPtr = nullptr;
     workEvent.init("(work event)", particleDataPtr);
   }
@@ -309,17 +336,17 @@ public:
       if (hooks[i]->canSetImpactParameter()) ++nCanSetImpactParameter;
     }
     if (nCanSetResonanceScale > 1) {
-      infoPtr->errorMsg("Error in UserHooksVector::initAfterBeams "
+      loggerPtr->ERROR_MSG(
         "multiple UserHooks with canSetResonanceScale() not allowed");
       return false;
     }
     if (nCanChangeFragPar > 1) {
-      infoPtr->errorMsg("Error in UserHooksVector::initAfterBeams "
+      loggerPtr->ERROR_MSG(
         "multiple UserHooks with canChangeFragPar() not allowed");
       return false;
     }
     if (nCanSetImpactParameter > 1) {
-      infoPtr->errorMsg("Error in UserHooksVector::initAfterBeams "
+      loggerPtr->ERROR_MSG(
         "multiple UserHooks with canSetImpactParameter() not allowed");
       return false;
     }
@@ -624,6 +651,33 @@ public:
     return false;
   }
 
+  // Set initial ends of a string to be fragmented. This is done once
+  // for each string. Note that the second string end may be zero in
+  // case we are hadronising a string piece leading to a junction.
+  virtual void setStringEnds( const StringEnd* pos, const StringEnd* neg,
+    vector<int> iPart) {
+    for ( int i = 0, N = hooks.size(); i < N; ++i )
+      hooks[i]->setStringEnds( pos, neg, iPart);
+  }
+
+  // Do change fragmentation parameters.
+  // Input: flavPtr, zPtr, pTPtr, idEnd, m2Had, iParton and posEnd (or
+  // negEnd).
+  virtual bool doChangeFragPar( StringFlav* sfIn, StringZ* zIn,
+    StringPT* ptIn, int idIn, double mIn, vector<int> parIn,
+    const StringEnd* endIn) {
+    for ( int i = 0, N = hooks.size(); i < N; ++i )
+      if ( hooks[i]->canChangeFragPar()
+           && hooks[i]->doChangeFragPar(sfIn, zIn, ptIn, idIn,
+                                     mIn, parIn, endIn) ) return true;
+    return false;}
+
+  // Can veto hadrons in the fragmentation.
+  virtual bool canVetoFragmentation() {
+    for ( int i = 0, N = hooks.size(); i < N; ++i )
+      if ( hooks[i]->canVetoFragmentation() ) return true;
+    return false;}
+
   // Do a veto on a hadron just before it is added to the final state.
   virtual bool doVetoFragmentation(Particle p, const StringEnd* nowEnd) {
     for ( int i = 0, N = hooks.size(); i < N; ++i )
@@ -640,6 +694,31 @@ public:
     return false;
   }
 
+  virtual bool doVetoFinalTwo(Particle p1, Particle p2,
+    const StringEnd* e1, const StringEnd* e2) {
+    for ( int i = 0, N = hooks.size(); i < N; ++i )
+      if ( hooks[i]->canChangeFragPar()
+        && hooks[i]->doVetoFinalTwo(p1, p2, e1, e2) ) return true;
+    return false;
+  }
+
+  // Possibility to veto an event after hadronization based on event
+  // contents. Works as an early trigger to avoid running the time
+  // consuming rescattering process on uninteresting events.
+  virtual bool canVetoAfterHadronization() {
+    for ( int i = 0, N = hooks.size(); i < N; ++i )
+      if ( hooks[i]->canVetoAfterHadronization() ) return true;
+    return false;
+  }
+
+  // Do the actual veto after hadronization.
+  virtual bool doVetoAfterHadronization(const Event& e) {
+    for ( int i = 0, N = hooks.size(); i < N; ++i )
+      if ( hooks[i]->canVetoAfterHadronization()
+        && hooks[i]->doVetoAfterHadronization(e) ) return true;
+    return false;
+  }
+
   // Can set the overall impact parameter for the MPI treatment.
   virtual bool canSetImpactParameter() const {
     for ( int i = 0, N = hooks.size(); i < N; ++i )
