@@ -1,5 +1,5 @@
 // VinciaEW.h is a part of the PYTHIA event generator.
-// Copyright (C) 2022 Peter Skands, Torbjorn Sjostrand.
+// Copyright (C) 2025 Peter Skands, Torbjorn Sjostrand.
 // PYTHIA is licenced under the GNU GPL v2 or later, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
@@ -159,6 +159,7 @@ public:
     partonSystemsPtr = infoPtr->partonSystemsPtr;
     rndmPtr          = infoPtr->rndmPtr;
     settingsPtr      = infoPtr->settingsPtr;
+    loggerPtr        = infoPtr->loggerPtr;
     alphaPtr         = alphaPtrIn;
     alphaSPtr        = alphaSPtrIn;
     isInitPtr        = true;
@@ -277,9 +278,9 @@ public:
   // Report helicity combination error for an FF antenna function.
   void hmsgFFAnt(int polMot, int poli, int polj) {
     stringstream ss;
-    ss << ": helicity combination was not found:\n    "
+    ss << "helicity combination was not found:\n    "
        << "polMot = " << polMot << " poli = " << poli << " polj = " << polj;
-    infoPtr->errorMsg("Error in " + __METHOD_NAME__, ss.str());}
+    loggerPtr->ERROR_MSG(ss.str());}
 
   // Initialize an II antenna function.
   void initIIAnt(int id1, int id2, int pol, const double& Q2,
@@ -289,9 +290,9 @@ public:
   // Report helicity combination error for an II antenna function.
   void hmsgIIAnt(int polA, int pola, int polj) {
     stringstream ss;
-    ss << ": helicity combination was not found:\n    "
+    ss << "helicity combination was not found:\n    "
        << "polA = " << polA << " pola = " << pola << " polj = " << polj;
-    infoPtr->errorMsg("Error in " + __METHOD_NAME__, ss.str());}
+    loggerPtr->ERROR_MSG(ss.str());}
 
   // FF Antenna functions for branching process I (K) -> i j (k).
   // Q2 is the offshellness of I.
@@ -369,9 +370,9 @@ public:
   // Report helicty combination error for an FSR splitting kernel.
   void hmsgFSRSplit(int polMot, int poli, int polj) {
     stringstream ss;
-    ss << ": helicity combination was not found:\n    "
+    ss << "helicity combination was not found:\n    "
        << "polMot = " << polMot << " poli = " << poli << " polj = " << polj;
-    infoPtr->errorMsg("Error in " + __METHOD_NAME__, ss.str());}
+    loggerPtr->ERROR_MSG(ss.str());}
 
   // Initialize an ISR splitting kernel.
   void initISRSplit(bool va, int id1, int id2, int pol,
@@ -386,9 +387,9 @@ public:
   // Report helicty combination error for an ISR splitting kernel.
   void hmsgISRSplit(int polA, int pola, int polj) {
     stringstream ss;
-    ss << ": helicity combination was not found:\n    "
+    ss << "helicity combination was not found:\n    "
        << "polA = " << polA << " pola = " << pola << " polj = " << polj;
-    infoPtr->errorMsg("Error in " + __METHOD_NAME__, ss.str());}
+    loggerPtr->ERROR_MSG(ss.str());}
 
   // Final-state splitting kernels.
   double ftofvFSRSplit(double Q2, double z, int idMot, int idi, int idj,
@@ -511,6 +512,7 @@ private:
   PartonSystems* partonSystemsPtr{};
   Rndm* rndmPtr{};
   Settings* settingsPtr{};
+  Logger* loggerPtr{};
   AlphaEM* alphaPtr{};
   AlphaStrong* alphaSPtr{};
 
@@ -574,6 +576,7 @@ class EWAntenna {
     AmpCalculator* ampCalcPtrIn) {
     infoPtr          = infoPtrIn;
     rndmPtr          = infoPtr->rndmPtr;
+    loggerPtr        = infoPtr->loggerPtr;
     partonSystemsPtr = infoPtr->partonSystemsPtr;
     vinComPtr        = vinComPtrIn;
     alphaPtr         = alphaPtrIn;
@@ -652,6 +655,7 @@ protected:
   EWBranching* brTrial{};
   Info* infoPtr{};
   Rndm* rndmPtr{};
+  Logger* loggerPtr{};
   PartonSystems* partonSystemsPtr{};
   VinciaCommon* vinComPtr{};
   AlphaEM* alphaPtr{};
@@ -732,7 +736,7 @@ class EWAntennaII : public EWAntenna {
 public:
 
   // Constructor.
-  EWAntennaII(BeamParticle* beamAPtrIn, BeamParticle* beamBPtrIn):
+  EWAntennaII(BeamParticlePtr beamAPtrIn, BeamParticlePtr beamBPtrIn):
     beamAPtr(beamAPtrIn), beamBPtr(beamBPtrIn), shh(0), xMot(0), xRec(0),
       vetoResonanceProduction(false), TINYPDFtrial(1e-10) {;}
 
@@ -749,8 +753,7 @@ private:
 
   // Members.
   // Beam pointers.
-  BeamParticle* beamAPtr{};
-  BeamParticle* beamBPtr{};
+  BeamParticlePtr beamAPtr{}, beamBPtr{};
   // Hadronic invariant mass.
   double shh;
   // Antenna hadronic momentum fractions.
@@ -796,11 +799,12 @@ public:
     partonSystemsPtr = infoPtr->partonSystemsPtr;
     rndmPtr          = infoPtr->rndmPtr;
     settingsPtr      = infoPtr->settingsPtr;
+    loggerPtr        = infoPtr->loggerPtr;
     vinComPtr = vinComPtrIn;
     al = alIn;}
 
   // Initialize.
-  void init(BeamParticle* beamAPtrIn, BeamParticle* beamBPtrIn)  {
+  void init(BeamParticlePtr beamAPtrIn, BeamParticlePtr beamBPtrIn)  {
   beamAPtr = beamAPtrIn; beamBPtr = beamBPtrIn;
   doVetoHardEmissions = settingsPtr->flag("Vincia:EWoverlapVeto");
   vetoHardEmissionsDeltaR2 =
@@ -839,7 +843,7 @@ public:
       ant.initPtr(infoPtr, vinComPtr, al, ampCalcPtr);
       // Initialise and if success, store.
       if (ant.init(event, iMot, iRec, iSysSav, it->second, settingsPtr)) {
-        antVec.push_back(move(ant));
+        antVec.push_back(std::move(ant));
         if (verbose >= VinciaConstants::DEBUG) {
           stringstream ss;
           ss << "Added EW antenna with iEv = "
@@ -880,22 +884,20 @@ public:
   // Update an event.
   void updateEvent(Event &event) {
     if (verbose >= VinciaConstants::DEBUG)
-      printOut(__METHOD_NAME__, "begin", VinciaConstants::dashLen);
+      printOut(__METHOD_NAME__, "begin", VinciaConstants::DASHLEN);
     if (antTrial != nullptr) antTrial->updateEvent(event);
-    else infoPtr->errorMsg("Error in " + __METHOD_NAME__,
-      ": trial doesn't exist!");
+    else loggerPtr->ERROR_MSG("trial doesn't exist!");
     if (verbose >= VinciaConstants::DEBUG)
-      printOut(__METHOD_NAME__, "end", VinciaConstants::dashLen);}
+      printOut(__METHOD_NAME__, "end", VinciaConstants::DASHLEN);}
 
   // Update parton systems.
   void updatePartonSystems(Event &event) {
     if (verbose >= VinciaConstants::DEBUG)
-      printOut(__METHOD_NAME__, "begin", VinciaConstants::dashLen);
+      printOut(__METHOD_NAME__, "begin", VinciaConstants::DASHLEN);
     if (antTrial!=nullptr) antTrial->updatePartonSystems(event);
-    else infoPtr->errorMsg("Error in " + __METHOD_NAME__,
-      ": trial doesn't exist!");
+    else loggerPtr->ERROR_MSG("trial doesn't exist!");
     if (verbose >= VinciaConstants::DEBUG)
-      printOut(__METHOD_NAME__, "end", VinciaConstants::dashLen);}
+      printOut(__METHOD_NAME__, "end", VinciaConstants::DASHLEN);}
 
   // Print the antennas.
   void printAntennae() {
@@ -941,11 +943,13 @@ private:
   double q2Cut;
 
   // Pointers.
-  BeamParticle* beamAPtr{}, *beamBPtr{};
+  BeamParticlePtr beamAPtr{};
+  BeamParticlePtr beamBPtr{};
   Info* infoPtr{};
   PartonSystems* partonSystemsPtr{};
   Rndm* rndmPtr{};
   Settings* settingsPtr{};
+  Logger* loggerPtr{};
   VinciaCommon* vinComPtr{};
   AlphaEM* al{};
 
@@ -993,6 +997,7 @@ public:
   void initPtr(Info* infoPtrIn, VinciaCommon* vinComPtrIn) override {
     infoPtr = infoPtrIn;
     particleDataPtr  = infoPtr->particleDataPtr;
+    loggerPtr        = infoPtr->loggerPtr;
     partonSystemsPtr = infoPtr->partonSystemsPtr;
     rndmPtr          = infoPtr->rndmPtr;
     settingsPtr      = infoPtr->settingsPtr;
@@ -1001,8 +1006,8 @@ public:
     isInitPtr = true;}
 
   // Initialise settings for current run (called as part of Pythia::init()).
-  void init(BeamParticle* beamAPtrIn = 0, BeamParticle* beamBPtrIn = 0)
-    override;
+  void init(BeamParticlePtr beamAPtrIn = nullptr,
+    BeamParticlePtr beamBPtrIn = nullptr) override;
 
   // Select helicities for a resonance-decay system.
   bool polarise(vector<Particle> &state) override {
@@ -1011,16 +1016,16 @@ public:
 
   // Prepare to shower a system.
   // (If isBelowHadIn = true, assume only resonance decays may be left to do.)
-  bool prepare(int iSysIn, Event &event, bool isBelowHadIn=false) override;
+  bool prepare(int iSysIn, Event &event, int scaleRegionIn = 0) override;
 
   // Update EW shower system each time something has changed.
   void update(Event &event, int iSysIn) override {
     if (verbose >= VinciaConstants::DEBUG)
-      printOut(__METHOD_NAME__, "begin", VinciaConstants::dashLen);
+      printOut(__METHOD_NAME__, "begin", VinciaConstants::DASHLEN);
     if (iSysIn != ewSystem.system()) return;
     else ewSystem.buildSystem(event);
     if (verbose >= VinciaConstants::DEBUG)
-      printOut(__METHOD_NAME__, "end", VinciaConstants::dashLen);}
+      printOut(__METHOD_NAME__, "end", VinciaConstants::DASHLEN);}
 
   // Set verbose level.
   void setVerbose(int verboseIn) override {
@@ -1041,35 +1046,32 @@ public:
   // Check veto.
   bool acceptTrial(Event& event) override {
     if (verbose >= VinciaConstants::DEBUG)
-      printOut(__METHOD_NAME__, "begin", VinciaConstants::dashLen);
+      printOut(__METHOD_NAME__, "begin", VinciaConstants::DASHLEN);
     bool success = false;
     if (ewSystem.hasTrial()) success = ewSystem.acceptTrial(event);
-    else infoPtr->errorMsg("Error in " + __METHOD_NAME__,
-      ": trial doesn't exist!");
+    else loggerPtr->ERROR_MSG("trial doesn't exist!");
     if (verbose >= VinciaConstants::DEBUG)
-      printOut(__METHOD_NAME__, "end", VinciaConstants::dashLen);
+      printOut(__METHOD_NAME__, "end", VinciaConstants::DASHLEN);
     return success;}
 
   // Update event after branching accepted.
   void updateEvent(Event& event) override {
     if (verbose >= VinciaConstants::DEBUG)
-      printOut(__METHOD_NAME__, "begin", VinciaConstants::dashLen);
+      printOut(__METHOD_NAME__, "begin", VinciaConstants::DASHLEN);
     if (ewSystem.hasTrial()) ewSystem.updateEvent(event);
-    else infoPtr->errorMsg("Error in " + __METHOD_NAME__,
-      ": trial doesn't exist!");
+    else loggerPtr->ERROR_MSG("trial doesn't exist!");
     if (verbose >=VinciaConstants::DEBUG) {
       printOut(__METHOD_NAME__,"Event after update:"); event.list();
-      printOut(__METHOD_NAME__, "end", VinciaConstants::dashLen);}}
+      printOut(__METHOD_NAME__, "end", VinciaConstants::DASHLEN);}}
 
   // Update partonSystems after branching accepted.
   void updatePartonSystems(Event& event) override {
     if (verbose >= VinciaConstants::DEBUG)
-      printOut(__METHOD_NAME__, "begin", VinciaConstants::dashLen);
+      printOut(__METHOD_NAME__, "begin", VinciaConstants::DASHLEN);
     if (ewSystem.hasTrial()) ewSystem.updatePartonSystems(event);
-    else infoPtr->errorMsg("Error in " + __METHOD_NAME__,
-      ": trial doesn't exist!");
+    else loggerPtr->ERROR_MSG("trial doesn't exist!");
     if (verbose >= VinciaConstants::DEBUG)
-      printOut(__METHOD_NAME__, "end", VinciaConstants::dashLen);}
+      printOut(__METHOD_NAME__, "end", VinciaConstants::DASHLEN);}
 
   // Clear EW system.
   void clear(int) override {
@@ -1131,8 +1133,8 @@ private:
     if (!attributeValue(line, attribute, valString)) return false;
     istringstream valStream(valString);
     if ( !(valStream >> val) ) {
-      infoPtr->errorMsg("Error in " + __METHOD_NAME__,
-        ": failed to store attribute " + attribute + " " + valString);
+      loggerPtr->ERROR_MSG("failed to store attribute "
+        + attribute + " " + valString);
       return false;
     } else return true;
   }
