@@ -1,5 +1,5 @@
 // VinciaISR.h is a part of the PYTHIA event generator.
-// Copyright (C) 2022 Peter Skands, Torbjorn Sjostrand.
+// Copyright (C) 2025 Peter Skands, Torbjorn Sjostrand.
 // PYTHIA is licenced under the GNU GPL v2 or later, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
@@ -88,8 +88,8 @@ public:
   virtual double getSj2(double Qt2, double zeta, double sAB);
 
   // Compute trial PDF ratio.
-  virtual double trialPDFratio(BeamParticle* beamAPtr, BeamParticle* beamBPtr,
-    int iSys, int idA, int idB, double eA, double eB,
+  virtual double trialPDFratio(BeamParticlePtr beamAPtr,
+    BeamParticlePtr beamBPtr, int iSys, int idA, int idB, double eA, double eB,
     double Qt2A, double Qt2B);
 
   // Return last trial PDF ratio.
@@ -107,6 +107,7 @@ public:
   Info*     infoPtr{};
   Rndm*     rndmPtr{};
   Settings* settingsPtr{};
+  Logger*   loggerPtr{};
 
   // Use m or pT evolution for collinear singularities.
   bool useMevolSav;
@@ -227,8 +228,8 @@ public:
     return TrialIIGCollA::getS1j(Qt2, zeta, sAB);}
 
   // Trial PDF ratio.
-  virtual double trialPDFratio(BeamParticle* beamAPtr, BeamParticle* beamBPtr,
-    int iSys, int idA, int idB, double eA, double eB,
+  virtual double trialPDFratio(BeamParticlePtr beamAPtr,
+    BeamParticlePtr beamBPtr, int iSys, int idA, int idB, double eA, double eB,
     double Qt2A, double Qt2B) override {
     // Note: arguments reversed intentionally!
     return TrialIIGCollA::trialPDFratio(
@@ -296,8 +297,8 @@ public:
   virtual double getSj2(double Qt2, double zeta, double sAB) override;
 
   // Trial PDF ratio.
-  virtual double trialPDFratio(BeamParticle* beamAPtr, BeamParticle* beamBPtr,
-    int iSys, int idA, int idB, double eA, double eB,
+  virtual double trialPDFratio(BeamParticlePtr beamAPtr,
+    BeamParticlePtr beamBPtr, int iSys, int idA, int idB, double eA, double eB,
     double Qt2A, double Qt2B) override;
 
 };
@@ -354,9 +355,9 @@ public:
     return TrialIISplitA::getS1j(Qt2, zeta, sAB);}
 
   // Trial PDF ratio.
-  virtual double trialPDFratio(BeamParticle* beamAPtr, BeamParticle* beamBPtr,
-    int iSys, int idA, int idB, double eA, double eB, double Qt2A, double Qt2B)
-    override {
+  virtual double trialPDFratio(BeamParticlePtr beamAPtr,
+    BeamParticlePtr beamBPtr, int iSys, int idA, int idB, double eA, double eB,
+    double Qt2A, double Qt2B) override {
     // Note: arguments reversed intentionally!
     return TrialIISplitA::trialPDFratio(beamBPtr, beamAPtr, iSys,
       idB, idA, eB, eA, Qt2B, Qt2A);}
@@ -414,8 +415,8 @@ public:
   virtual double getSj2(double Qt2, double zeta, double sAB) override;
 
   // Trial PDF ratio.
-  virtual double trialPDFratio(BeamParticle* beamAPtr, BeamParticle* beamBPtr,
-    int iSys, int idA, int idB, double eA, double eB,
+  virtual double trialPDFratio(BeamParticlePtr beamAPtr,
+    BeamParticlePtr beamBPtr, int iSys, int idA, int idB, double eA, double eB,
     double Qt2A, double Qt2B) override;
 
 };
@@ -462,8 +463,8 @@ public:
     return TrialIIConvA::getS1j(Qt2, zeta, sAB);}
 
   // Trial PDF ratio
-  virtual double trialPDFratio(BeamParticle* beamAPtr, BeamParticle* beamBPtr,
-    int iSys, int idA, int idB, double eA, double eB,
+  virtual double trialPDFratio(BeamParticlePtr beamAPtr,
+    BeamParticlePtr beamBPtr, int iSys, int idA, int idB, double eA, double eB,
     double Qt2A, double Qt2B) override {
     // Note: arguments reversed intentionally!
     return TrialIIConvA::trialPDFratio(
@@ -522,8 +523,8 @@ public:
   virtual double getSj2(double Qt2, double zeta, double sAK) override;
 
   // Trial PDF ratio.
-  virtual double trialPDFratio(BeamParticle* beamAPtr, BeamParticle* beamBPtr,
-    int iSys, int idA, int idK, double eA, double eK,
+  virtual double trialPDFratio(BeamParticlePtr beamAPtr,
+    BeamParticlePtr beamBPtr, int iSys, int idA, int idK, double eA, double eK,
     double Qt2A, double Qt2B) override;
 
 };
@@ -604,8 +605,8 @@ class TrialIFGCollA : public TrialGeneratorISR {
   virtual double getSj2(double Qt2, double zeta, double sAK) override;
 
   // Trial PDF ratio (= just a simple headroom factor).
-  virtual double trialPDFratio(BeamParticle* beamAPtr, BeamParticle* beamBPtr,
-    int iSys, int idA, int idK, double eA, double eK,
+  virtual double trialPDFratio(BeamParticlePtr beamAPtr,
+    BeamParticlePtr beamBPtr, int iSys, int idA, int idK, double eA, double eK,
     double Qt2A, double Qt2B) override;
 
 };
@@ -661,8 +662,8 @@ class TrialIFGCollK : public TrialGeneratorISR {
   virtual double getSj2(double Qt2, double zeta, double sAK) override;
 
   // Trial PDF ratio.
-  virtual double trialPDFratio(BeamParticle* beamAPtr, BeamParticle* beamBPtr,
-    int iSys, int idA, int idK, double eA, double eK,
+  virtual double trialPDFratio(BeamParticlePtr beamAPtr,
+    BeamParticlePtr beamBPtr, int iSys, int idA, int idK, double eA, double eK,
     double Qt2A, double Qt2B) override;
 };
 
@@ -725,8 +726,8 @@ public:
   virtual double getSj2(double Qt2, double zeta, double sAK) override;
 
   // Trial PDF ratio.
-  virtual double trialPDFratio(BeamParticle* beamAPtr, BeamParticle* beamBPtr,
-    int iSys, int idA, int idK, double eA, double eK,
+  virtual double trialPDFratio(BeamParticlePtr beamAPtr,
+    BeamParticlePtr beamBPtr, int iSys, int idA, int idK, double eA, double eK,
     double Qt2A, double Qt2B) override;
 
 };
@@ -783,8 +784,8 @@ class TrialIFSplitK : public TrialGeneratorISR {
   virtual double getSj2(double Qt2, double zeta, double sAK) override;
 
   // Trial PDF ratio.
-  virtual double trialPDFratio(BeamParticle* beamAPtr, BeamParticle* beamBPtr,
-    int iSys, int idA, int idK, double eA, double eK,
+  virtual double trialPDFratio(BeamParticlePtr beamAPtr,
+    BeamParticlePtr beamBPtr, int iSys, int idA, int idK, double eA, double eK,
     double Qt2A, double Qt2B) override;
 
 };
@@ -843,8 +844,8 @@ public:
   virtual double getSj2(double Qt2, double zeta, double sAK) override;
 
   // Trial PDF ratio.
-  virtual double trialPDFratio(BeamParticle* beamAPtr, BeamParticle* beamBPtr,
-    int iSys, int idA, int idK, double eA, double eK,
+  virtual double trialPDFratio(BeamParticlePtr beamAPtr,
+    BeamParticlePtr beamBPtr, int iSys, int idA, int idK, double eA, double eK,
     double Qt2A, double Qt2B) override;
 
 };
@@ -1071,7 +1072,7 @@ public:
   virtual ~VinciaISR() {;}
 
   // Initialize shower. Possibility to force re-initialization by hand.
-  void init(BeamParticle* beamAPtrIn, BeamParticle* beamBPtrIn) override;
+  void init(BeamParticlePtr beamAPtrIn, BeamParticlePtr beamBPtrIn) override;
 
   // Force reset at beginning of each event.
   void onBeginEvent() override { isPrepared = false; }
@@ -1188,7 +1189,7 @@ public:
     else return alphaSptr->Lambda6();}
 
   // Add trial functions to a BranchElemental.
-  void resetTrialGenerators(BranchElementalISR* trial);
+  void resetTrialGenerators(shared_ptr<BranchElementalISR> trial);
 
   // Method to check if a gluon splitting in the initial state (to get
   // rid of heavy quarks) is still possible after the current
@@ -1247,25 +1248,26 @@ private:
     double qMinNow);
 
   // Generate trial branching kinematics and check physical phase space
-  bool generateKinematics(Event& event, BranchElementalISR* trialPtr,
-    vector<Vec4>& pRec) {
+  bool generateKinematics(Event& event,
+    shared_ptr<BranchElementalISR> trialPtr, vector<Vec4>& pRec) {
     return ( trialPtr->isII()
       ? generateKinematicsII(event, trialPtr, pRec)
       : generateKinematicsIF(event, trialPtr, pRec) ); }
 
   // Generate kinematics (II) and set flavours and masses.
-  bool generateKinematicsII(Event& event, BranchElementalISR* trialPtr,
-    vector<Vec4>& pRec);
+  bool generateKinematicsII(Event& event,
+    shared_ptr<BranchElementalISR> trialPtr, vector<Vec4>& pRec);
 
   // Generate kinematics (IF) and set flavours and masses.
-  bool generateKinematicsIF(Event& event, BranchElementalISR* trialPtr,
-    vector<Vec4>& pRec);
+  bool generateKinematicsIF(Event& event,
+    shared_ptr<BranchElementalISR> trialPtr, vector<Vec4>& pRec);
 
   // Main trial accept function.
-  bool acceptTrial(const Event& event, BranchElementalISR* winnerPtr);
+  bool acceptTrial(const Event& event,
+    shared_ptr<BranchElementalISR> winnerPtr);
 
   // Method to assign colour flow.
-  bool assignColourFlow(Event& event, BranchElementalISR* trialPtr);
+  bool assignColourFlow(Event& event, shared_ptr<BranchElementalISR> trialPtr);
 
   // Initialised.
   bool isInit;
@@ -1288,13 +1290,13 @@ private:
   // Shower parameters.
   bool helicityShower, sectorShower, convGluonToQuarkI, convQuarkToGluonI;
   bool kineMapIFretry;
-  int nGluonToQuarkI, nGluonToQuarkF;
+  int nGluonToQuark;
   double cutoffScaleII, cutoffScaleIF;
   int nFlavZeroMass;
 
-  // Factorization scale and shower starting settings.
-  int    pTmaxMatch;
-  double pTmaxFudge, pT2maxFudge, pT2maxFudgeMPI;
+  // Shower starting-scale settings.
+  int    pTmaxMatch{}, pTdampMatch{};
+  double pTmaxFudge{}, pT2maxFudge{}, pT2maxFudgeMPI{}, pTdampFudge{};
 
   // AlphaS parameters.
   bool useCMW;
@@ -1353,24 +1355,26 @@ private:
   vector<double> regMinScalesNow;
 
   // Vector of dipoles (with trial branchings, 4 at most).
-  vector<BranchElementalISR > branchElementals;
+  vector<shared_ptr<BranchElementalISR> > branchElementals;
 
   // Current winner.
-  BranchElementalISR* winnerPtr{};
+  shared_ptr<BranchElementalISR> winnerPtr{};
   int indxWin;
   int iSysWin;
   vector<Particle> stateNew;
   VinciaClustering minClus;
 
   // Flags to tell a few basic properties of each parton system.
-  map<int, bool> isHardSys, isResonanceSys, polarisedSys, doMECsSys;
+  map<int, bool> isHardSys{}, isResonanceSys{}, polarisedSys{}, doMECsSys{};
 
   // Saved particle state and number in event record.
-  map<int, vector< Particle > > partsSav;
-  map<int, vector< int      > > indexSav;
+  map<int, vector< Particle > > partsSav{};
+  map<int, vector< int      > > indexSav{};
 
   // Save initial ISR starting scale system by system.
-  map<int, double> Q2hat;
+  map<int, double> q2Hat{};
+  vector<bool> doPTlimit{}, doPTdamp{};
+  map<int, double> pT2damp{};
 
   // Count the number of branchings in the system.
   map<int, int> nBranch, nBranchISR;
