@@ -1,5 +1,5 @@
 // VinciaMergingHooks.h is a part of the PYTHIA event generator.
-// Copyright (C) 2022 Torbjorn Sjostrand, Peter Skands.
+// Copyright (C) 2025 Torbjorn Sjostrand, Peter Skands.
 // PYTHIA is licenced under the GNU GPL v2 or later, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUidELINES for details.
 
@@ -234,10 +234,11 @@ class VinciaHardProcess : public HardProcess {
  public:
 
   // Constructor.
-  VinciaHardProcess(Info* infoPtrIn, int verboseIn, bool resolveDecaysIn,
+  VinciaHardProcess(Logger* loggerPtrIn, int verboseIn, bool resolveDecaysIn,
     bool doHEFTIn, bool doVBFIn) :
-    verbose(verboseIn), infoPtr(infoPtrIn), resolveDecays(resolveDecaysIn),
-      doHEFT(doHEFTIn), doVBF(doVBFIn), isInit(false) {defineMultiparticles();}
+    verbose(verboseIn), loggerPtr(loggerPtrIn),
+      resolveDecays(resolveDecaysIn), doHEFT(doHEFTIn), doVBF(doVBFIn),
+      isInit(false) {defineMultiparticles();}
 
   // Initialise process.
   void initOnProcess(string process, ParticleData* particleData) override;
@@ -301,8 +302,8 @@ private:
   // Verbosity.
   int verbose;
 
-  // Pointer to info in Pythia.
-  Info* infoPtr{};
+  // Logger object.
+  Logger* loggerPtr{};
 
   // Flag to control how resonances are handled.
   bool resolveDecays;
@@ -355,16 +356,15 @@ class VinciaMergingHooks : public MergingHooks {
   virtual double tmsNow(const Event& event) override;
 
   // Check whether an event should be vetoed due to branching above tMS.
-  virtual bool canVetoStep() override;
-  virtual bool doVetoStep(const Event& process, const Event& event, bool)
-    override;
+  virtual bool doVetoStep(const Event& process,
+    const Event& event, bool) override;
+
+  // Check whether a branching should be vetoed because it is above tMS.
+  virtual bool doVetoEmission(const Event&) override;
 
   // Overridden base class methods.
-  virtual bool doVetoEmission(const Event&) override {return false;}
-  virtual bool canVetoEmission() override {return false;}
   virtual double dampenIfFailCuts(const Event& ) override {return 0.;}
-  virtual int getNumberOfClusteringSteps(const Event&, bool) override {
-    return 0;}
+  virtual int getNumberOfClusteringSteps(const Event&, bool) override;
   virtual bool canCutOnRecState() override {return false;}
   virtual bool doCutOnRecState(const Event&) override {return false;}
   virtual bool canVetoTrialEmission() override {return false;}
@@ -373,9 +373,6 @@ class VinciaMergingHooks : public MergingHooks {
   virtual bool useShowerPlugin() override {return false;}
   virtual double hardProcessME(const Event&) override {return 0;}
 
-  // Others.
-  virtual double tmsDefinition( const Event&) override {return 0.;}
-
   // Set and get verbosity.
   void setVerbose(int verboseIn) {verbose = verboseIn;}
   int getVerbose() {return verbose;}
@@ -495,6 +492,8 @@ class VinciaMergingHooks : public MergingHooks {
  private:
 
   // Merging scale implementations.
+  double pTlast(const Event& event);
+  double pTvincia(const Event& event, int ii, int ij, int ik);
   double kTmin(const Event& event);
   vector<double> cutsMin(const Event& event);
 
